==> zego_zpns-2.3.0%2B1.tar.gz: lib/src/internal/call_kit_engine.dart <==
import 'package:flutter/services.dart';
import 'package:zego_zpns/src/internal/zpns_converter.dart';
import 'package:zego_zpns/src/internal/zpns_event_handler_impl.dart';
import 'package:zego_zpns/src/internal/zpns_settings.dart';
import 'package:zego_zpns/src/ios_utils/internal/uuid_impl.dart';
import '../call_kit_api.dart';
import '../call_kit_defines.dart';
class CallKitEngine implements CallKit{
  CallKitEngine() {
    // if(configuration == null){
    //   throw PlatformException(
    //       code: "1",
    //       message:
    //       "Please invoke SetInitConfiguration before invoke CallKit getInstance");
    // }
    ZPNsEventHandlerImpl.registerEventHandler();
  }

  @override
  Future<void> reportIncomingCall(CXCallUpdate cxCallUpdate, UUID uuid) async{
    return await ZPNsSettings.channel.invokeMethod('reportIncomingCallWithTitle',{'cxCallUpdate':ZPNsConverter.mCXCallUpdate(cxCallUpdate),'uuidSeq':(uuid as UUIDImpl).seq});
  }


  @override
  Future<void> reportCallEnded(CXCallEndedReason endedReason, UUID uuid) async{
    return await ZPNsSettings.channel.invokeMethod('reportCallEnded',{'uuidSeq':(uuid as UUIDImpl).seq,'endedReason':CXCallEndedReasonExtension.valueMap[endedReason]});
  }

  @override
  Future<void> reportCallUpdate(CXCallUpdate cxCallUpdate, UUID uuid) async{
    return await ZPNsSettings.channel.invokeMethod('reportCallUpdate',{'cxCallUpdate':ZPNsConverter.mCXCallUpdate(cxCallUpdate),'uuidSeq':(uuid as UUIDImpl).seq});
  }

  @override
  Future<void> reportOutgoingCall(UUID uuid) async{
    return await ZPNsSettings.channel.invokeMethod('reportOutgoingCall',{'uuidSeq':(uuid as UUIDImpl).seq});
  }



}

class CXActionImpl implements CXAction{

  int seq;

  @override
  fail() {
    ZPNsSettings.channel.invokeMethod('callKitActionFail',{'seq':seq});
  }

  @override
  fulfill() {
    ZPNsSettings.channel.invokeMethod('callKitActionFulfill',{'seq':seq});
  }

  CXActionImpl({required this.seq});
}

==> zego_zpns-2.3.1%2B1.tar.gz: lib/src/internal/call_kit_engine.dart <==
import 'package:flutter/services.dart';
import 'package:zego_zpns/src/internal/zpns_converter.dart';
import 'package:zego_zpns/src/internal/zpns_event_handler_impl.dart';
import 'package:zego_zpns/src/internal/zpns_settings.dart';
import 'package:zego_zpns/src/ios_utils/internal/uuid_impl.dart';
import '../call_kit_api.dart';
import '../call_kit_defines.dart';
class CallKitEngine implements CallKit{
  CallKitEngine() {
    // if(configuration == null){
    //   throw PlatformException(
    //       code: "1",
    //       message:
    //       "Please invoke SetInitConfiguration before invoke CallKit getInstance");
    // }
    ZPNsEventHandlerImpl.registerEventHandler();
  }

  // @override
  // Future<void> reportIncomingCall(CXCallUpdate cxCallUpdate, UUID uuid) async{
  //   return await ZPNsSettings.channel.invokeMethod('reportIncomingCallWithTitle',{'cxCallUpdate':ZPNsConverter.mCXCallUpdate(cxCallUpdate),'uuidSeq':(uuid as UUIDImpl).seq});
  // }


  @override
  Future<void> reportCallEnded(CXCallEndedReason endedReason, UUID uuid) async{
    return await ZPNsSettings.channel.invokeMethod('reportCallEnded',{'uuidSeq':(uuid as UUIDImpl).seq,'endedReason':CXCallEndedReasonExtension.valueMap[endedReason]});
  }

  @override
  Future<void> reportCallUpdate(CXCallUpdate cxCallUpdate, UUID uuid) async{
    return await ZPNsSettings.channel.invokeMethod('reportCallUpdate',{'cxCallUpdate':ZPNsConverter.mCXCallUpdate(cxCallUpdate),'uuidSeq':(uuid as UUIDImpl).seq});
  }

  @override
  Future<void> reportOutgoingCall(UUID uuid) async{
    return await ZPNsSettings.channel.invokeMethod('reportOutgoingCall',{'uuidSeq':(uuid as UUIDImpl).seq});
  }



}

class CXActionImpl implements CXAction{

  String seq;

  @override
  fail() {
    ZPNsSettings.channel.invokeMethod('callKitActionFail',{'seq':seq});
  }

  @override
  fulfill() {
    ZPNsSettings.channel.invokeMethod('callKitActionFulfill',{'seq':seq});
  }

  CXActionImpl({required this.seq});
}
